@@ -1,7 +1,7 @@
 package App::daftarnama::reseller;
 
-our $DATE = '2018-12-17'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2021-05-26'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: CLI to access reseller API on DaftarNama.id
@@ -18,7 +18,7 @@ App::daftarnama::reseller - CLI to access reseller API on DaftarNama.id
 
 =head1 VERSION
 
-This document describes version 0.002 of App::daftarnama::reseller (from Perl distribution App-daftarnama-reseller), released on 2018-12-17.
+This document describes version 0.003 of App::daftarnama::reseller (from Perl distribution App-daftarnama-reseller), released on 2021-05-26.
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-daftarnama-resel
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-daftarnama-reseller>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-daftarnama-reseller/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -50,7 +50,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
